from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\x00\x30\x42\x96\xc6\xc2\x27\xcf\x44\x82\x50\xff\xfe\x50\xfe\x06\x00\x00\x00\x00\x00\x00\x00\x00\x79\x11\xcd\x08\x91\xcc\x7f\xbf\x78\xa4\xda\x98\xac\xc9\xae\x07\x57\x31\xd2\x09\x7b\xc8\xc5\x7e\xb7\xc9\x31\x6e\x2a\xfe\x5b\x36\x81\x5a\x8f\x86\xaf\x77\x4d\x56\x1f\xf1\xe7\x3b\xb1\xa6\xdf\x4d\x4b\xf8\x65\xbd\x30\x3f\x0b\xec\x48\x7d\x74\xf6\xdb\x89\xcf\xf7\xda\x8e\xfa\x66\xde\x06\x12\x9f\x1f\x7e\xe3\xdf\xbe\xea\xc5\x79\x72\x41\x16\x1f\xc2\x1a\x54\x1c\xfa\x57\xce\x89\x6d\x34\xc8\x36\xad\x49\xd7\xb4\xbe\xd7\x4b\xcf\x81\x5e\xbd\x92\x74\x17\x78\x64\x54\xea\x26\x90\xd5\xf5\xfb\x11\x93\x8c\x85\x42\x42\xe2\x28\x09\x31\xd4\x12\x0b\x3b\x75\xc3\x58\x62\xe1\x42\x44\xcc\x8b\x60\xf7\x60\x1a\x96\x82\x38\x11\x4a\xa9\x68\x28\x02\x1d\xf4\x4f\x8d\xed\x6b\x7d\x4a\xb5\xc5\x87\x96\x26\x07\x23\x7b\x00\xe7\xbb\xff\x7f\x59\xb4\x77\x57\x6b\x27\x8d\x33\x27\xee\x99\xf3\x9c\x97\xaf\x0b\x41\x50\xd7\xac\xb2\x52\xf6\x28\x91\x8f\x63\xdd\xeb\x4c\x3e\x51\x54\xa1\x56\x22\xb0\x4e\xbe\xb1\x34\x64\x21\xcc\x4d\xf8\x09\xa1\x73\x95\x00\x90\x97\x96\xc1\xcd\xe3\x9c\xd1\x16\xb7\x21\x58\x5d\x12\x41\xf6\x0d\x40\x0b\x02\x26\x62\x38\x40\x9f\xb5\xe3\x6d\xe2\x40\x93\xc0\xb4\xc9\x4f\xee\x4d\xba\x10\xb4\xff\x67\x45\x94\xa8\x25\x45\xd9\x29\x19\xd3\x03\xea\x25\x65\x4a\x99\x09\xcd\xbe\xd8\x0b\x74\x25\x78\x6e\xc1\x1f\x05\xb8\x95\xa6\x42\x25\xf9\x5a\x5d\x4c\x2a\xc6\x77\x74\x6d\x08\x11\x00\x0c\xf9\x64\x2b\xda\xc9\x67\x5a\x91\xf4\x7e\xa4\xde\x95\x4f\x0b\xf6\xef\x43\xd9\x47\xb8\x60\xf9\x61\x79\xe0\x7f\x19\x48\xd5\xb9\xfd\xaf\x1f\x48\xdf\xf9\x51\x30\x3f\xdb\x28\xf3\xbc\xac\xb2\xd2\x68\xdf\x35\x95\x7d\x95\xd9\xd7\x79\xda\xe6\x89\x0f\x02\xe9\x60\x75\x5b\xd6\xa1\xb2\xdf\x8a\x30\x93\xb1\x6e\x6c\xfa\xe0\x2d\xc9\xbc\xd2\xf5\x2b\x49\x82\x3e\x25\x0d\x45\xb8\x02\xac\xb2\xb7\xe4\x05\x8c\xd2\xd2\x74\x8f\xe9\xf6\x8d\x27\x02\x88\xb2\x2f\x4a\x87\x7e\xdf\x4d\x68\xcc\xe5\x58\x8c\x01\xf5\xeb\x43\xde\x82\xce\x31\xb0\xea\xdb\xcd\x99\xe1\xf9\x54\xb0\x95\x6e\xda\xde\x09\x5e\xa2\x67\x05\x9f\x2b\xdc\xed\xb2\x90\x40\xe0\xae\x4d\x0e\x5c\xfb\x10\x80\x37\x04\x8a\xa2\x44\x09\xa3\x87\xf0\x3a\x79\x49\x5c\xa8\x4f\xad\x9a\x65\xfa\xab\x64\x69\xea\x63\x32\x79\x33\x76\x8b\x3e\x30\x82\x90\x70\xb9\xdf\x02\xf0\x66\x3c\x57\x84\x71\x68\xf1\xbb\xef\x68\x9c\x15\xeb\xae\x6d\x99\xcd\xd7\x95\xce\x75\xd5\xa2\xab\xfb\x80\x13\x84\x40\x1f\x95\xd8\xa5\x66\x09\x96\xdf\x8f\x46\x96\x90\x5c\xe1\xcb\x2b\x2a\x9b\xb7\x6a\x7a\x17\x72\x24\xc7\x38\xbf\xae\x3c\xd6\xdd\xe3\x65\xb2\xb7\xdb\x7e\x70\x6d\xf0\xaa\x8e\x94\x16\xc7\x9e\xc2\x2e\x52\xb9\x02\x5f\x6a\x25\x13\x19\x04\xd9\x1e\x4e\x38\xab\x61\x7d\x6b\xf2\xfe\x39\xe0\x27\x03\x72\x72\x0b\xcc\x2f\x90\x1b\x40\x9e\x54\x73\x2d\x76\xe8\x4c\xf4\x9e\xb2\x00\xce\x3f\x1a\xfa\x91\xec\xed\x0d\x58\xe0\x28\x3c\x0d\xb1\x3e\x79\xb0\xa9\xb1\xc5\x52\xe4\x4e\xde\x1b\x10\xf4\x7f\x8e\xf8\x33\x45\xbf\xb7\x31\xc0\xde\x3b\xf6\x49\xb2\xe2\x4e\x0b\x65\xf5\xe0\x2f\x01\xeb\xe4\xd0\x92\x3d\x3e\x62\xc1\x50\xa8\x4f\xa1\x3b\x8a\xbb\x88\x28\xc9\x97\x20\x1a\x73\x50\xf6\x64\xe2\x62\x90\x8e\xfc\x40\x9b\x7e\xfc\xa7\x8d\x5e\xd3\xb2\x3b\x24\x30\x93\x2f\x38\x97\x98\x6c\xef\x9a\xec\xa5\xb5\xfc\x79\x9b\x8b\xf3\xab\x00\x81\xa9\x3d\x21\x98\x33\x88\x83\x12\xc1\x6c\xbd\x15\x5f\xe7\x43\x28\x99\xc5\xf2\x24\x0b\x56\x5b\x67\x99\xdc\x84\x07\x20\x4c\xb9\x00\x2a\xd7\x9e\x78\xf9\x47\x99\xf5\x68\xb8\xab\xee\xf7\x1c\x0d\x85\x7f\xf0\x9d\x52\x1e\x2a\x6c\x13\x3b\x30\x2c\x95\xfb\x29\x97\xdd\xf3\xf9\x77\xd7\xc9\x99\x23\x06\x8b\xf4\xd6\x05\xe8\x19\xc9\x83\x38\x3a\x34\x9d\x2b\x0b\x02\x8c\x41\x12\x31\x68\xfe\x7e\x53\xd3\x5b\xa5\xea\xf1\x00\x43\xd2\x97\xf6\xf8\x57\x52\xd6\xb4\xc3\xfd\x04\x9c\x30\xf6\xfc\x6f\xc2\x1f\x77\x90\xfa\x6b\xd1\x4a\xc5\x63\x71\x08\x67\x80\x02\x94\x25\x8d\x74\x2e\x59\x67\xbd\xa6\x66\x26\xb2\x4c\xeb\x21\x10\x23\x60\x93\x07\x65\xbe\x8d\xdb\x26\xea\x6c\xd4\xae\xee\x29\xb4\x73\x64\x95\x52\x9c\xb6\xd8\x36\xe9\x51\x58\x4b\x76\x6d\xfb\xf7\x70\x0b\xf3\x37\xb0\xb9\x16\x89\x8d\x09\xea\x80\x88\x1b\x9e\xd1\xc6\x54\x99\xa2\x3e\x20\x8e\x5d\x25\xef\x86\xf5\xda\x9e\xfa\x67\x2d\x8b\xf0\xd9\x8c\x40\x52\xa4\xaa\x54\x70\x6c\xc7\x0d\xab\x8e\xaa\x10\x81\x4f\xa1\x43\x60\x6f\x8f\xb6\x32\x67\x96\x55\xc6\x9c\xbe\x4d\x46\x72\xc5\x52\x81\x8a\x1f\xa3\x1d\x17\x7d\x82\xd0\xe7\xf6\x90\xe2\xa9\x50\xaa\x88\x92\x00\xe0\x28\xad\xb7\x27\xfd\xc7\x43\xdc\xf1\xd9\x3e\xf1\x6f\xb8\x02\x33\xdd\x61\x1d\xdf\xac\xe8\x7d\x8a\x0e\xe1\xa8\xc0\x13\x45\x91\x74\x61\x86\x56\x48\xe5\x2e\xca\xe9\x06\xbb\x9e\xb6\x09\xa1\x23\x2a\x86\xde\x0e\xb5\x5c\x0f\xd2\xaf\x20\xa9\x3c\xda\xfb\xdf\x11\xd3\xdd\x01\xe6\x5f\xff\x57\xf2\x22\x97\xd6\x27\x61\x35\xab\x7a\xdf\x62\x51\xe1\x3a\x42\x3f\x60\xa3\x0c\x6f\x44\xd4\x07\x2d\x41\x2b\x58\x67\x1c\x90\x80\x25\xe2\x24\x6c\x54\x04\x7a\x97\x5f\xfe\x04\x81\xb9\x7d\xd5\xde\x1f\x29\x00\xff\xb8\xd5\xd1\xe3\x4c\x7f\x55\xd6\x57\x50\x74\xf1\x77\x7b\x7e\x04\x00\x71\xbf\x40\x31\x5d\xae\x34\xb2\x16\x5e\xf3\xcd\xec\xd7\xfb\xd8\xf7\x4c\xdc\xf7\xfa\x93\x1a\x6c\xf8\x33\xca\x1e\x21\x33\x1d\xa7\x75\x12\x09\xe3\x4d\x01\x56\x1b\x80\xc8\xa6\xa7\xbf\x23\x4a\xad\x22\x23\x31\x7f\x2c\x32\x34\x6b\x69\xcb\xf1\x48\x18\xc1\xee\xa0\x6d\x79\xe5\xe3\x60\x31\x40\xbf\xd1\x68\x7f\xc9\x21\x43\xae\x64\xde\x2b\x2a\x49\xab\xf3\x91\xe7\x4c\x26\xf5\x5e\x27\xee\xeb\xc5\x56\x9e\x46\x05\xc3\x60\x26\x73\x9b\x78\x6e\xae\x63\xce\x97\xe1\xb9\x74\xbe\xc2\x70\x68\xba\xfa\x6c\xe3\xc6\x47\xa4\x3a\x94\x58\x60\xe1\xab\xa0\x36\x1c\x0b\x56\x02\x44\x4a\x9b\x8f\xa1\xb6\xc7\x87\xe4\x37\xbd\xbd\x29\x5c\x35\xbf\xe5\x4f\xef\x16\xa3\xc9\x42\x1d\xa9\x8f\x15\x49\x64\x20\x4c\xe2\x9f\xec\xb2\x3c\x65\xf8\xfb\x6e\x45\x7f\x4a\x23\x9f\x59\xdf\x31\x45\xd2\xe7\xa2\x78\x57\xa7\x3a\x19\xbe\xa4\xbb\x9e\x9e\x82\x87\x88\xe6\x64\xff\x58\x9b\x96\x90\x7b\xfa\x4a\x66\xc7\x23\x11\xce\x56\x62\x81\x12\xc3\xc0\x9d\x58\x69\x91\x87\x72\x69\x76\x7f\x88\xb5\xdd\x84\xb6\xdd\x4b\x6f\xa4\xe2\x4e\xfb\x57\x9b\xda\xc7\xf6\x15\xb8\x56\xd4\xbe\xbc\x18\xf2\x05\x4e\x68\x13\x0e\x61\x0f\xa5\x6c\xbb\xc3\xa8\x6f\x4b\xc0\x64\xa3\x8f\x73\x66\xa5\xe9\xcf\xf1\x9f\xf0\xed\x75\xa4\x79\xe6\x68\x95\xe6\xb2\x99\x9e\x96\x9e\xc6\x97\x2c\xc2\x36\x7d\x73\x05\x81\x03\xca\x84\x6e\xd0\x81\x61\x61\xd5\xd9\x2d\xb4\x40\xb3\x98\x60\xe8\x3c\x66\xfc\x69\x81\x4a\x0c\x7c\x9c\xb6\x73\x3a\x0d\xc7\xbd\xda\x2c\x3b\x13\x17\x1c\xf7\x00\xcc\xdf\x7a\x01\x83\x20\x61\x89\x33\xef\x4e\x91\x00\x84\x9d\x11\xd6\x01\xfc\x70\x10\x1a\x45\x58\x75\xd3\x9f\x39\x34\x54\xa1\x19\xc1\x04\x4c\x07\xff\xb5\x56\x22\xfa\xd0\xf2\xf3\xc6\xf1\x3a\x3b\x02\xf5\x65\x30\xa3\xe8\x02\xe6\xe0\x0e\xef\xfa\x06\x2c\x44\x1f\x2d\xbc\xa2\x4c\x7f\xf1\x2e\x55\xa8\x38\xce\xb1\xd9\x1f\x5f\x58\xca\x4b\xc6\x47\x1a\xb3\x60\x8d\xe3\x09\x8e\x32\x4d\x99\x5e\x71\x1c\x49\x97\x40\x48\xe1\xaa\x7b\x8b\xb6\x5e\xf1\x7a\xd1\x2e\xa4\x88\x88\x1c\xa4\x09\xca\x88\x18\x10\xf1\xb6\xa4\xeb\x51\xe1\x8b\x8d\xfa\x87\x83\x66\x76\x88\x0c\xd7\xfc\xbd\xe2\xbb\x7e\xe9\x80\x6b\x1b\xe1\x7e\xd8\x53\x2d\xda\x99\xa7\x63\xf8\x4f\x5a\xe2\x24\x48\x97\xc7\x90\x0f\x35\xb4\x1e\x4d\xb4\x6c\x5b\xb0\x1e\xc8\x24\xdb\xa4\x82\xc8\x21\x70\xdc\x5b\x41\x21\x63\x45\x05\x4a\x3e\x03\xdb\x20\xe5\x52\x0a\x74\xdc\x87\x62\x6a\xa4\x6a\x36\xb1\xaa\x98\x87\x4b\xb6\xa8\x46\x63\xa3\xbf\x28\x91\xc7\x06\x73\xd7\x9d\x77\x51\x2c\x38\xc5\xd5\xdf\xeb\x23\x8c\xbe\x0e\x84\x60\xac\x9f\x64\xe8\x6b\xfb\xc9\xce\x34\xbb\xa8\x59\xe3\x53\x24\x4e\xde\x85\x83\x1b\xab\xab\x5c\x96\x2e\x36\x78\xee\xd0\xe7\xce\xa7\xc2\xec\x9a\xfc\x97\x24\xe6\x31\x5f\xd4\x2f\xb6\x34\xec\x82\x10\x50\xb1\x31\xe0\x36\x9b\xd7\xe4\x92\x0e\xc2\xa9\xa7\x34\xf8\x7f\x7a\x56\x5d\x55\x44\x1a\x35\xe5\x3e\xe5\xcc\xe3\xbf\x96\x58\x85\xa0\x24\x9d\x35\xa2\x95\xec\x18\x41\x8f\x92\xe4\x21\xc0\xc7\xd6\xa7\x05\x2a\x36\xd2\x18\xf3\x59\xe4\xd1\x82\x0e\x46\xfe\xee\x10\xbd\x2e\x9c\x13\x56\xea\x20\xe1\xe2\x2f\x36\x1a\x2e\xeb\x84\x68\x55\x90\x70\x65\xc0\x2c\xa2\xe6\x41\xb4\xbd\xfd\xf9\x20\xf9\x03\x6a\xc6\x4e\x7e\x8c\xe3\xac\xf9\xf7\x70\x95\x10\x02\x13\xb4\x3f\xa6\x40\x62\xbf\x03\xc4\xd9\x53\xd3\xd6\x7e\x58\x60\x71\xce\xc9\xba\x5f\x36\xca\x50\xd4\x4c\x04\x94\x29\xca\x41\xdd\x32\x8e\xb2\x12\xc0\xa7\x3d\x6f\x94\x10\xca\x14\x08\x47\x1a\xc6\x26\x4b\x9d\x94\x1a\x49\x62\xc4\x88\xa8\xfe\xec\x1f\xa1\xea\x00\x34\xe8\x2b\x82\x83\x4a\x7b\xbb\xb5\xe7\x3f\x87\x2c\x36\x84\x74\x72\xf0\xd5\xbf\x2a\xbe\xde\x61\x1a\xe6\xcf\xec\x85\xef\xbc\xd3\x80\xef\x54\xf8\xa9\x07\x3e\xbc\xdf\x3e\x81\xb0\xdb\xc6\x8c\xa5\x1b\xf5\xe1\xa0\x71\x0e\x9c\xa5\xda\x89\xbd\x4d\xf3\x17\x1e\xa5\x53\x45\x5c\x0a\x95\x1d\xc7\x68\xb5\x73\x08\xd3\xc0\x83\xb9\xd7\x22\x7f\x06\x3f\xee\x5c\x79\xf7\x41\x75\xa1\x28\x71\x9e\xc6\x58\x2e\x90\x96\x58\x75\xf9\x3f\x18\x0c\x2f\xa6\x42\xc6\x61\x93\xe2\x49\xe7\x92\x89\xe3\x54\x81\x62\xed\xee\x71\x35\xac\xa9\x5f\x2c\x9a\x1f\xfd\xae\x62\x26\x31\x9d\xf1\xc7\x1f\x60\x0b\x90\xe9\xb5\xf1\xe5\xee\xa4\xf5\x08\x6a\x7f\xb9\xd0\x4e\x51\x43\x76\x52\x21\x37\x3b\x53\x3f\xb4\x99\xaf\x20\xf8\xc3\x17\x0a\xf2\x19\xe7\xad\xb9\x55\xf1\x81\xc2\x1a\x1e\x87\x22\xac\x04\xf8\x73\xa0\x8f\xa4\x58\xeb\x33\xf5\x9e\xe3\xb8\xf7\x2d\x37\xae\xea\xac\x10\x61\xb8\x1f\xad\x5e\x78\x18\x9a\xda\x92\x56\x6a\x60\xc8\xe6\x0a\xe7\x81\x28\x4d\x1a\x6d\xf2\xea', 2)

# cleanup
del pyarmor_runtime

